@@ -29,7 +29,7 @@ def _notify(msg):
 
 def warning(msg, application, execution_time, environment, user_id=None, extra_data=None):
         config = AutoConfig(search_path='/var/www/html/pytestee')
-        print(config)
+        print(config('WARNING'))
 
         _log(msg, application,config('WARNING') ,execution_time, environment, user_id, extra_data)
         
